Class: Macro
- Inherits:
-
Object
- Object
- Macro
- Defined in:
- lib/ruby-macrodroid/macro.rb
Instance Attribute Summary collapse
-
#actions ⇒ Object
readonly
Returns the value of attribute actions.
-
#constraints ⇒ Object
readonly
Returns the value of attribute constraints.
-
#description ⇒ Object
Returns the value of attribute description.
-
#deviceid ⇒ Object
readonly
Returns the value of attribute deviceid.
-
#local_variables ⇒ Object
readonly
Returns the value of attribute local_variables.
-
#remote_url ⇒ Object
Returns the value of attribute remote_url.
-
#title ⇒ Object
Returns the value of attribute title.
-
#triggers ⇒ Object
readonly
Returns the value of attribute triggers.
Instance Method Summary collapse
- #add(obj) ⇒ Object
- #import_h(h) ⇒ Object
- #import_xml(node) ⇒ Object
-
#initialize(name = nil, geofences: nil, deviceid: nil, remote_url: nil, debug: false) ⇒ Macro
constructor
A new instance of Macro.
- #match?(triggerx, detail = {time: $env[:time]}, model = nil) ⇒ Boolean
-
#run ⇒ Object
invokes the actions.
-
#set_env ⇒ Object
prepares the environment in order for triggers to test fire successfully Used for testing.
- #set_var(label, v = '') ⇒ Object
- #to_h ⇒ Object
- #to_pc ⇒ Object
- #to_s(colour: false) ⇒ Object
- #to_summary(colour: false) ⇒ Object
Constructor Details
#initialize(name = nil, geofences: nil, deviceid: nil, remote_url: nil, debug: false) ⇒ Macro
Returns a new instance of Macro.
352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/ruby-macrodroid/macro.rb', line 352 def initialize(name=nil, geofences: nil, deviceid: nil, remote_url: nil, debug: false) @title, @geofences, @deviceid, @debug = name, geofences, deviceid, debug @remote_url = remote_url puts 'inside Macro#initialize' if @debug @local_variables, @triggers, @actions, @constraints = {}, [], [], [] @h = {} end |
Instance Attribute Details
#actions ⇒ Object (readonly)
Returns the value of attribute actions.
348 349 350 |
# File 'lib/ruby-macrodroid/macro.rb', line 348 def actions @actions end |
#constraints ⇒ Object (readonly)
Returns the value of attribute constraints.
348 349 350 |
# File 'lib/ruby-macrodroid/macro.rb', line 348 def constraints @constraints end |
#description ⇒ Object
Returns the value of attribute description.
350 351 352 |
# File 'lib/ruby-macrodroid/macro.rb', line 350 def description @description end |
#deviceid ⇒ Object (readonly)
Returns the value of attribute deviceid.
348 349 350 |
# File 'lib/ruby-macrodroid/macro.rb', line 348 def deviceid @deviceid end |
#local_variables ⇒ Object (readonly)
Returns the value of attribute local_variables.
348 349 350 |
# File 'lib/ruby-macrodroid/macro.rb', line 348 def local_variables @local_variables end |
#remote_url ⇒ Object
Returns the value of attribute remote_url.
350 351 352 |
# File 'lib/ruby-macrodroid/macro.rb', line 350 def remote_url @remote_url end |
#title ⇒ Object
Returns the value of attribute title.
350 351 352 |
# File 'lib/ruby-macrodroid/macro.rb', line 350 def title @title end |
#triggers ⇒ Object (readonly)
Returns the value of attribute triggers.
348 349 350 |
# File 'lib/ruby-macrodroid/macro.rb', line 348 def triggers @triggers end |
Instance Method Details
#add(obj) ⇒ Object
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/ruby-macrodroid/macro.rb', line 365 def add(obj) if obj.kind_of? Trigger then puts 'trigger found' if @debug @triggers << obj elsif obj.kind_of? Action puts 'action found' if @debug @actions << obj elsif obj.kind_of? Constraint puts 'constraint found' if @debug @constraints << obj end end |
#import_h(h) ⇒ Object
413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'lib/ruby-macrodroid/macro.rb', line 413 def import_h(h) if @debug then puts 'inside import_h' puts 'h:' + h.inspect end @category = h[:category] @title = h[:name] @description = h[:description] # fetch the local variables if h[:local_variables].any? and h[:local_variables].first.any? then @local_variables = h[:local_variables].map do |var| val = case var[:type] when 0 # boolean var[:boolean_value] when 1 # integer var[:int_value] when 2 # string var[:string_value] when 3 # decimal var[:decimal_Value] end [var[:name], val] end.to_h end # fetch the triggers @triggers = h[:trigger_list].map do |trigger| puts 'trigger: ' + trigger.inspect if @debug #exit object(trigger.to_snake_case) end @actions = h[:action_list].map do |action| object(action.to_snake_case) end puts 'before fetch constraints' if @debug # fetch the constraints @constraints = h[:constraint_list].map do |constraint| object(constraint.to_snake_case) end puts 'after fetch constraints' if @debug @h = h %i(local_variables m_trigger_list m_action_list m_constraint_list)\ .each {|x| @h[x] = [] } puts 'after @h set' if @debug @h end |
#import_xml(node) ⇒ Object
471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 |
# File 'lib/ruby-macrodroid/macro.rb', line 471 def import_xml(node) if @debug then puts 'inside Macro#import_xml' puts 'node: ' + node.xml.inspect end if node.element('triggers') then # level 2 @title = node.attributes[:name] @category = node.attributes[:category] @description = node.attributes[:description] # get all the triggers @triggers = node.xpath('triggers/*').map do |e| puts 'e.name: ' + e.name.inspect if @debug {timer: TimerTrigger}[e.name.to_sym].new(e.attributes.to_h) end # get all the actions @actions = node.xpath('actions/*').map do |e| if e.name == 'notification' then case e.attributes[:type].to_sym when :popup e.attributes.delete :type ToastAction.new e.attributes.to_h end end end # get all the constraints @constraints = node.xpath('constraints/*').map do |e| puts 'e.name: ' + e.name.inspect if @debug {airplanemode: AirplaneModeConstraint}[e.name.to_sym].new(e.attributes.to_h) end else # Level 1 puts 'import_xml: inside level 1' if @debug @title = node.text('macro') || node.attributes[:name] node.xpath('variable').each {|e| set_var(*e.text.to_s.split(/: */,2)) } #@description = node.attributes[:description] tp = TriggersNlp.new(self) @triggers = node.xpath('trigger').flat_map do |e| r = tp.find_trigger e.text puts 'found trigger ' + r.inspect if @debug item = e.element('item') if item then if item.element('description') then item.xpath('description').map do |description| inner_lines = description.text.to_s.strip.lines puts 'inner_lines: ' + inner_lines.inspect if @debug trigger = if e.text.to_s.strip.empty? then inner_lines.shift.strip else e.text.strip end puts 'trigger: ' + trigger.inspect if @debug r = tp.find_trigger trigger puts 'r: ' + r.inspect if @debug #o = r[0].new([description, self]) if r o = object_create(r[0], [description, self]) if r puts 'after o' if @debug o end else trigger = e.text.strip r = tp.find_trigger trigger a = e.xpath('item/*') h = if a.any? then a.map {|node| [node.name.to_sym, node.text.to_s]}.to_h else {} end r = tp.find_trigger trigger #r[0].new(h) if r if r then object_create(r[0], h) else raise MacroError, 'App-routes: Trigger "' + trigger + '" not found' end end else trigger = e.text.strip r = tp.find_trigger trigger #r[0].new(r[1]) if r if r then object_create(r[0],r[1]) else raise MacroError, 'App-routes: Trigger "' + trigger + '" not found' end end end ap = ActionsNlp.new self @actions = node.xpath('action').flat_map do |e| puts 'action e: ' + e.xml.inspect if @debug puts 'e.text ' + e.text if @debug item = e.element('item') if item then if item.element('description') then item.xpath('description').map do |description| inner_lines = description.text.to_s.strip.lines puts 'inner_lines: ' + inner_lines.inspect if @debug action = if e.text.to_s.strip.empty? then inner_lines.shift.strip else e.text.strip end puts 'action: ' + action.inspect if @debug r = ap.find_action action puts 'r: ' + r.inspect if @debug puts 'description: ' + description.xml.inspect if @debug #o = r[0].new([description, self]) if r o = object_create(r[0],[description, self]) if r puts 'after o' if @debug o end else action = e.text.strip puts 'action: ' + action.inspect if @debug r = ap.find_action action a = e.xpath('item/*') h = if a.any? then a.map {|node| [node.name.to_sym, node.text.to_s]}.to_h else {} end puts 'h: ' + h.inspect if @debug #r = ap.find_action action #r[0].new(h.merge(macro: self)) if r object_create(r[0], h.merge(macro: self)) if r end else action = e.text.strip r = ap.find_action action #r[0].new(r[1]) if r object_create(r[0],r[1]) if r end end cp = ConstraintsNlp.new @constraints = node.xpath('constraint').map do |e| r = cp.find_constraint e.text puts 'found constraint ' + r.inspect if @debug object_create(r[0], r[1]) if r end end self end |
#match?(triggerx, detail = {time: $env[:time]}, model = nil) ⇒ Boolean
691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 |
# File 'lib/ruby-macrodroid/macro.rb', line 691 def match?(triggerx, detail={time: $env[:time]}, model=nil ) if @triggers.any? {|x| x.type == triggerx and x.match?(detail, model) } then if @debug then puts 'checking constraints ...' puts '@constraints: ' + @constraints.inspect end if @constraints.all? {|x| x.match?($env.merge(detail), model) } then true else return false end end end |
#run ⇒ Object
invokes the actions
716 717 718 |
# File 'lib/ruby-macrodroid/macro.rb', line 716 def run() @actions.map(&:invoke) end |
#set_env ⇒ Object
prepares the environment in order for triggers to test fire successfully Used for testing
723 724 725 |
# File 'lib/ruby-macrodroid/macro.rb', line 723 def set_env() @triggers.each(&:set_env) end |
#set_var(label, v = '') ⇒ Object
727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 |
# File 'lib/ruby-macrodroid/macro.rb', line 727 def set_var(label, v='') value = if v.to_f.to_s == v v.to_f elsif v.downcase == 'true' true elsif v.downcase == 'false' false elsif v.to_i.to_s == v v.to_i else v end if not @local_variables.has_key? label.to_sym then @local_variables.merge!({label.to_sym => value}) end varify(label, value) end |
#to_h ⇒ Object
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 |
# File 'lib/ruby-macrodroid/macro.rb', line 386 def to_h() a = @local_variables.map do |k,v| varify(k,v).to_camelcase.map{|key,value| ['m_' + key, value]}.to_h end h = { local_variables: a, m_trigger_list: @triggers.map(&:to_h), m_action_list: @actions.map(&:to_h), m_category: @category, m_constraint_list: @constraints.map(&:to_h), m_description: '', m_name: title(), m_excludeLog: false, m_GUID: guid(), m_isOrCondition: false, m_enabled: true, m_descriptionOpen: false, m_headingColor: 0 } puts 'h: ' + h.inspect if @debug @h.merge(h) end |
#to_pc ⇒ Object
748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 |
# File 'lib/ruby-macrodroid/macro.rb', line 748 def to_pc() heading = '# ' + @title heading += '\n# ' + @description if @description condition = @triggers.first.to_pc actions = @actions.map(&:to_pc).join("\n") <<EOF #{heading} if #{condition} then #{actions} end EOF end |
#to_s(colour: false) ⇒ Object
764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 |
# File 'lib/ruby-macrodroid/macro.rb', line 764 def to_s(colour: false) indent = 0 #@actions.map(&:to_s).join.lines.length > 0 ? 1 : 0 a = [] a << '# ' + @category + "\n" if @category a << (colour ? "m".bg_cyan.gray.bold : 'm') + ': ' + @title if @description and @description.length >= 1 then a << (colour ? "d".bg_gray.gray.bold : 'd') + ': ' \ + @description.gsub(/\n/,"\n ") end if @local_variables.length >= 1 then vars = @local_variables.map do |k,v| label = colour ? 'v'.bg_magenta : 'v' label += ': ' label + "%s: %s" % [k,v] end a << vars.join("\n") end puts 'before triggers' if @debug a << @triggers.map do |x| puts 'x: ' + x.inspect if @debug raise 'Macro#to_s trigger cannot be nil' if x.nil? s =-x.to_s(colour: colour) puts 's: ' + s.inspect if @debug s2 = if s.lines.length > 1 then "\n" + s.lines.map {|x| x.prepend (' ' * (indent+1)) }.join else ' ' + s end puts 's2: ' + s2.inspect if @debug #s.lines > 1 ? "\n" + x : x (colour ? "t".bg_red.gray.bold : 't') + ":" + s2 end.join("\n") puts 'before actions' if @debug actions = @actions.map do |x| puts 'x: ' + x.inspect if @debug raise 'Macro#to_s action cannot be nil' if x.nil? s = x.to_s(colour: colour) #puts 's: ' + s.inspect r = if indent <= 0 then lines = s.lines if lines.length > 1 then s = lines.map {|x| x.prepend (' ' * (indent+1)) }.join end s2 = s.lines.length > 1 ? "\n" + s : ' ' + s if colour then "a".bg_blue.gray.bold + ":" + s2 else "a:" + s2 end elsif indent > 0 if s =~ /^Else/ then (' ' * (indent-1)) + "%s" % s elsif s =~ /^End/ indent -= 1 (' ' * indent) + "%s" % s else s2 = s.lines[0] + s.lines[1..-1].map {|x| (' ' * indent) + x }.join (' ' * indent) + "%s" % s2 end end if s =~ /^(?:If|DO \/ WHILE)/i then if indent < 1 then r = if colour then "a".bg_blue.gray.bold + ":\n %s" % s else "a:\n %s" % s end indent += 1 else r = (' ' * indent) + "%s" % s end indent += 1 end r end.join("\n") a << actions puts 'before constraints' if @debug if @constraints.any? then a << @constraints.map do |x| (colour ? "c".bg_green.gray.bold : 'c') + ": %s" % x end.join("\n") end a.join("\n") + "\n" end |
#to_summary(colour: false) ⇒ Object
894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 |
# File 'lib/ruby-macrodroid/macro.rb', line 894 def to_summary(colour: false) if colour then a = [ 'm'.bg_cyan.gray.bold + ': ' + @title, 't'.bg_red.gray.bold + ': ' + @triggers.map \ {|x| x.to_summary(colour: false)}.join(", "), 'a'.bg_blue.gray.bold + ': ' + @actions.map \ {|x| x.to_summary(colour: false)}.join(", ") ] if @constraints.any? then a << 'c'.bg_green.gray.bold + ': ' + @constraints.map \ {|x| x.to_summary(colour: false)}.join(", ") end else a = [ 'm: ' + @title, 't: ' + @triggers.map {|x| x.to_summary(colour: false)}.join(", "), 'a: ' + @actions.map {|x| x.to_summary(colour: false)}.join(", ") ] if @constraints.any? then a << 'c: ' + @constraints.map \ {|x| x.to_summary(colour: false)}.join(", ") end end a.join("\n") + "\n" end |