Class: Macro
- Inherits:
-
Object
- Object
- Macro
- Defined in:
- lib/ruby-macrodroid.rb
Instance Attribute Summary collapse
-
#actions ⇒ Object
readonly
Returns the value of attribute actions.
-
#constraints ⇒ Object
readonly
Returns the value of attribute constraints.
-
#description ⇒ Object
Returns the value of attribute description.
-
#local_variables ⇒ Object
readonly
Returns the value of attribute local_variables.
-
#title ⇒ Object
Returns the value of attribute title.
-
#triggers ⇒ Object
readonly
Returns the value of attribute triggers.
Instance Method Summary collapse
- #add(obj) ⇒ Object
- #import_h(h) ⇒ Object
- #import_xml(node) ⇒ Object
-
#initialize(name = nil, geofences: geofences, debug: false) ⇒ Macro
constructor
A new instance of Macro.
- #match?(triggerx, detail = {time: $env[:time]}, model = nil) ⇒ Boolean
-
#run ⇒ Object
invokes the actions.
-
#set_env ⇒ Object
prepares the environment in order for triggers to test fire successfully Used for testing.
- #to_h ⇒ Object
- #to_pc ⇒ Object
- #to_s ⇒ Object
- #to_summary ⇒ Object
Constructor Details
#initialize(name = nil, geofences: geofences, debug: false) ⇒ Macro
Returns a new instance of Macro.
403 404 405 406 407 408 409 410 411 412 |
# File 'lib/ruby-macrodroid.rb', line 403 def initialize(name=nil, geofences: geofences, debug: false) @title, @geofences, @debug = name, geofences, debug puts 'inside Macro#initialize' if @debug @local_variables, @triggers, @actions, @constraints = [], [], [], [] @h = {} end |
Instance Attribute Details
#actions ⇒ Object (readonly)
Returns the value of attribute actions.
400 401 402 |
# File 'lib/ruby-macrodroid.rb', line 400 def actions @actions end |
#constraints ⇒ Object (readonly)
Returns the value of attribute constraints.
400 401 402 |
# File 'lib/ruby-macrodroid.rb', line 400 def constraints @constraints end |
#description ⇒ Object
Returns the value of attribute description.
401 402 403 |
# File 'lib/ruby-macrodroid.rb', line 401 def description @description end |
#local_variables ⇒ Object (readonly)
Returns the value of attribute local_variables.
400 401 402 |
# File 'lib/ruby-macrodroid.rb', line 400 def local_variables @local_variables end |
#title ⇒ Object
Returns the value of attribute title.
401 402 403 |
# File 'lib/ruby-macrodroid.rb', line 401 def title @title end |
#triggers ⇒ Object (readonly)
Returns the value of attribute triggers.
400 401 402 |
# File 'lib/ruby-macrodroid.rb', line 400 def triggers @triggers end |
Instance Method Details
#add(obj) ⇒ Object
414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 |
# File 'lib/ruby-macrodroid.rb', line 414 def add(obj) if obj.kind_of? Trigger then puts 'trigger found' if @debug @triggers << obj elsif obj.kind_of? Action puts 'action found' if @debug @actions << obj elsif obj.kind_of? Constraint puts 'constraint found' if @debug @constraints << obj end end |
#import_h(h) ⇒ Object
457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/ruby-macrodroid.rb', line 457 def import_h(h) if @debug then puts 'inside import_h' puts 'h:' + h.inspect end @title = h[:name] @description = h[:description] # fetch the local variables @local_variables = h['local_variables'] # fetch the triggers @triggers = h[:trigger_list].map do |trigger| object(trigger.to_snake_case) end @actions = h[:action_list].map do |action| object(action.to_snake_case) end # fetch the constraints @constraints = h[:constraint_list].map do |constraint| object(constraint.to_snake_case) end @h = h i(local_variables m_trigger_list m_action_list m_constraint_list)\ .each {|x| @h[x] = [] } @h end |
#import_xml(node) ⇒ Object
495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/ruby-macrodroid.rb', line 495 def import_xml(node) if @debug then puts 'inside Macro#import_xml' puts 'node: ' + node.xml.inspect end if node.element('triggers') then # level 2 @title = node.attributes[:name] @description = node.attributes[:description] # get all the triggers @triggers = node.xpath('triggers/*').map do |e| puts 'e.name: ' + e.name.inspect if @debug {timer: TimerTrigger}[e.name.to_sym].new(e.attributes.to_h) end # get all the actions @actions = node.xpath('actions/*').map do |e| if e.name == 'notification' then case e.attributes[:type].to_sym when :popup e.attributes.delete :type ToastAction.new e.attributes.to_h end end end # get all the constraints @constraints = node.xpath('constraints/*').map do |e| puts 'e.name: ' + e.name.inspect if @debug {airplanemode: AirplaneModeConstraint}[e.name.to_sym].new(e.attributes.to_h) end else # Level 1 puts 'import_xml: inside level 1' if @debug @title = node.text('macro') || node.attributes[:name] #@description = node.attributes[:description] tp = TriggersNlp.new @triggers = node.xpath('trigger').map do |e| r = tp.find_trigger e.text puts 'found trigger ' + r.inspect if @debug if r then if r[0] == GeofenceTrigger then GeofenceTrigger.new(r[1], geofences: @geofences) else r[0].new(r[1]) end end end ap = ActionsNlp.new @actions = node.xpath('action').map do |e| puts 'action e: ' + e.xml.inspect if @debug r = ap.find_action e.text puts 'found action ' + r.inspect if @debug if r then a = e.xpath('item/*') h = if a.any? then a.map {|node| [node.name.to_sym, node.text.to_s]}.to_h else {} end r[0].new(r[1].merge(h)) end end cp = ConstraintsNlp.new @constraints = node.xpath('constraint').map do |e| r = cp.find_constraint e.text puts 'found constraint ' + r.inspect if @debug if r then r[0].new(r[1]) end end end self end |
#match?(triggerx, detail = {time: $env[:time]}, model = nil) ⇒ Boolean
611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 |
# File 'lib/ruby-macrodroid.rb', line 611 def match?(triggerx, detail={time: $env[:time]}, model=nil ) if @triggers.any? {|x| x.type == triggerx and x.match?(detail, model) } then if @debug then puts 'checking constraints ...' puts '@constraints: ' + @constraints.inspect end if @constraints.all? {|x| x.match?($env.merge(detail), model) } then true else return false end end end |
#run ⇒ Object
invokes the actions
636 637 638 |
# File 'lib/ruby-macrodroid.rb', line 636 def run() @actions.map(&:invoke) end |
#set_env ⇒ Object
prepares the environment in order for triggers to test fire successfully Used for testing
643 644 645 |
# File 'lib/ruby-macrodroid.rb', line 643 def set_env() @triggers.each(&:set_env) end |
#to_h ⇒ Object
435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/ruby-macrodroid.rb', line 435 def to_h() h = { local_variables: @local_variables, m_trigger_list: @triggers.map(&:to_h), m_action_list: @actions.map(&:to_h), m_constraint_list: @constraints.map(&:to_h), m_description: '', m_name: title(), m_excludeLog: false, m_GUID: guid(), m_isOrCondition: false, m_enabled: false, m_descriptionOpen: false, m_headingColor: 0 } puts 'h: ' + h.inspect if @debug @h.merge(h) end |
#to_pc ⇒ Object
647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/ruby-macrodroid.rb', line 647 def to_pc() heading = '# ' + @title heading += '\n# ' + @description if @description condition = @triggers.first.to_pc actions = @actions.map(&:to_pc).join("\n") "\#{heading}\n\nif \#{condition} then\n\#{actions}\nend\n" end |
#to_s ⇒ Object
663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 |
# File 'lib/ruby-macrodroid.rb', line 663 def to_s() indent = 0 actions = @actions.map do |x| s = x.to_s r = if indent <= 0 then "a: %s" % s elsif indent > 0 if s =~ /^Else/ then (' ' * (indent-1)) + "%s" % s elsif s =~ /^End/ indent -= 1 (' ' * indent) + "%s" % s else (' ' * indent) + "%s" % s end end if s =~ /^If/i then if indent < 1 then r = "a:\n %s" % s indent += 1 else r = (' ' * indent) + "%s" % s end indent += 1 end r end.join("\n") a = [ 'm: ' + @title, @triggers.map {|x| "t: %s" % x}.join("\n"), actions ] a << @constraints.map {|x| "c: %s" % x}.join("\n") if @constraints.any? if @description and @description.length >= 1 then a.insert(1, 'd: ' + @description.gsub(/\n/,"\n ")) end a.join("\n") + "\n" end |
#to_summary ⇒ Object
718 719 720 721 722 723 724 725 726 727 728 729 730 |
# File 'lib/ruby-macrodroid.rb', line 718 def to_summary() a = [ 'm: ' + @title, 't: ' + @triggers.map(&:to_summary).join(", "), 'a: ' + @actions.map(&:to_summary).join(", "), ] a << 'c: ' + @constraints.map(&:to_summary).join(", ") if @constraints.any? a.join("\n") + "\n" end |